from themoviedb.routes_async._base import Base
from themoviedb.routes_async.authentication import Authentication
from themoviedb.routes_async.certifications import Certifications
from themoviedb.routes_async.credit import Credit
from themoviedb.routes_async.companies import Company
from themoviedb.routes_async.collections import Collection
from themoviedb.routes_async.discover import Discover
from themoviedb.routes_async.episode_groups import EpisodeGroup
from themoviedb.routes_async.episodes import Episode
from themoviedb.routes_async.find import Find
from themoviedb.routes_async.genres import Genres
from themoviedb.routes_async.keywords import Keyword
from themoviedb.routes_async.movies import Movie, Movies
from themoviedb.routes_async.people import People, Person
from themoviedb.routes_async.network import Network
from themoviedb.routes_async.guest import Guest
from themoviedb.routes_async.reviews import Review
from themoviedb.routes_async.search import Search
from themoviedb.routes_async.seasons import Season
from themoviedb.routes_async.trending import Trending
from themoviedb.routes_async.tv import TV, TVs
from themoviedb.routes_async.watch_providers import WatchProviders
