from themoviedb.routes_sync._base import Base
from themoviedb.routes_sync.authentication import Authentication
from themoviedb.routes_sync.certifications import Certifications
from themoviedb.routes_sync.credit import Credit
from themoviedb.routes_sync.companies import Company
from themoviedb.routes_sync.collections import Collection
from themoviedb.routes_sync.discover import Discover
from themoviedb.routes_sync.episode_groups import EpisodeGroup
from themoviedb.routes_sync.episodes import Episode
from themoviedb.routes_sync.find import Find
from themoviedb.routes_sync.genres import Genres
from themoviedb.routes_sync.keywords import Keyword
from themoviedb.routes_sync.movies import Movie, Movies
from themoviedb.routes_sync.people import People, Person
from themoviedb.routes_sync.network import Network
from themoviedb.routes_sync.guest import Guest
from themoviedb.routes_sync.reviews import Review
from themoviedb.routes_sync.search import Search
from themoviedb.routes_sync.seasons import Season
from themoviedb.routes_sync.trending import Trending
from themoviedb.routes_sync.tv import TV, TVs
from themoviedb.routes_sync.watch_providers import WatchProviders
